Module: Elastics::ApiStubs

Included in:
Elastics
Defined in:
lib/elastics/api_stubs.rb

Class Method Summary collapse

Class Method Details

.analyze_index(*vars) ⇒ Object

########## Elastics.analyze_index ##########

API Name: Analyze API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-analyze.html


Elastics::Template::Api

analyze_index:

  • GET
  • "/<>/_analyze"

Usage: Elastics.analyze_index :index => nil

Notice: You can pass the text to analyze as the :data variable (or the param :text). You can pass the parameters as the :params variable.



1021
1022
1023
1024
# File 'lib/elastics/api_stubs.rb', line 1021

def self.analyze_index(*vars)
  ## this is a stub, used for reference
  super
end

.cat(*vars) ⇒ Object

########## Elastics.cat ##########

API Name: Cat API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cat.html


Elastics::Template::Api

cat:

  • GET
  • "/"

Usage: Elastics.cat Notice: You must pass the :path variable or you can pass it as a simple string argument: Elastics.cat('/path')



1435
1436
1437
1438
# File 'lib/elastics/api_stubs.rb', line 1435

def self.cat(*vars)
  ## this is a stub, used for reference
  super
end

.close_index(*vars) ⇒ Object

########## Elastics.close_index ##########

API Name: Open/Close Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html


Elastics::Template::Api

close_index:

  • POST
  • "/<>/_close"

Usage: Elastics.close_index :index => nil



688
689
690
691
# File 'lib/elastics/api_stubs.rb', line 688

def self.close_index(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_health(*vars) ⇒ Object

########## Elastics.cluster_health ##########

API Name: Health API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-health.html


Elastics::Template::Api

cluster_health:

  • GET
  • "/_cluster/health/<>"

Usage: Elastics.cluster_health :index => nil

Notice: You can pass the params as the :params variable.



1459
1460
1461
1462
# File 'lib/elastics/api_stubs.rb', line 1459

def self.cluster_health(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_nodes_hot_threads(*vars) ⇒ Object

########## Elastics.cluster_nodes_hot_threads ##########

API Name: Nodes Hot Threads API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html


Elastics::Template::Api

cluster_nodes_hot_threads:

  • GET
  • "/_nodes/<<nodes= ~ >>/hot_threads"

Usage: Elastics.cluster_nodes_hot_threads :nodes => nil



1669
1670
1671
1672
# File 'lib/elastics/api_stubs.rb', line 1669

def self.cluster_nodes_hot_threads(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_nodes_info(*vars) ⇒ Object

########## Elastics.cluster_nodes_info ##########

API Name: Nodes Info API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-info.html


Elastics::Template::Api

cluster_nodes_info:

  • GET
  • "/_nodes/<<nodes= ~ >>/<<info= ~ >>"

Usage: Elastics.cluster_nodes_info :nodes => nil, :info => nil

Notice: This template uses the _nodes shortcut.



1647
1648
1649
1650
# File 'lib/elastics/api_stubs.rb', line 1647

def self.cluster_nodes_info(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_nodes_stats(*vars) ⇒ Object

########## Elastics.cluster_nodes_stats ##########

API Name: Nodes Stats API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-stats.html


Elastics::Template::Api

cluster_nodes_stats:

  • GET
  • "/_nodes/<<nodes= ~ >>/stats/<<stats= ~ >>"

Usage: Elastics.cluster_nodes_stats :nodes => nil, :stats => nil

Notice: You can pass the params as the :params variable. You must pass the data structure as the :data variable.



1622
1623
1624
1625
# File 'lib/elastics/api_stubs.rb', line 1622

def self.cluster_nodes_stats(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_pending_tasks(*vars) ⇒ Object

########## Elastics.cluster_pending_tasks ##########

API Name: Pending Cluster Tasks API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-pending.html


Elastics::Template::Api

cluster_pending_tasks:

  • GET
  • "/_cluster/pending_tasks"

Usage: Elastics.cluster_pending_tasks Notice: You can pass the params as the :params variable.



1530
1531
1532
1533
# File 'lib/elastics/api_stubs.rb', line 1530

def self.cluster_pending_tasks(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_reroute(*vars) ⇒ Object

########## Elastics.cluster_reroute ##########

API Name: Cluster Reroute API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-reroute.html


Elastics::Template::Api

cluster_reroute:

  • POST
  • "/_cluster/reroute"

Usage: Elastics.cluster_reroute Notice: You must pass the data structure as the :data variable.



1553
1554
1555
1556
# File 'lib/elastics/api_stubs.rb', line 1553

def self.cluster_reroute(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_state(*vars) ⇒ Object

########## Elastics.cluster_state ##########

API Name: State API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-state.html


Elastics::Template::Api

cluster_state:

  • GET
  • "/_cluster/state/<<metrics= _all >>/<>"

Usage: Elastics.cluster_state :metrics => "_all", :index => nil

Notice: You can pass the metrics as the :metrics variable.



1484
1485
1486
1487
# File 'lib/elastics/api_stubs.rb', line 1484

def self.cluster_state(*vars)
  ## this is a stub, used for reference
  super
end

.cluster_stats(*vars) ⇒ Object

########## Elastics.cluster_stats ##########

API Name: Stats API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-stats.html


Elastics::Template::Api

cluster_stats:

  • GET
  • "/_cluster/stats"

Usage: Elastics.cluster_stats Notice: You can pass the params as the :params variable.



1507
1508
1509
1510
# File 'lib/elastics/api_stubs.rb', line 1507

def self.cluster_stats(*vars)
  ## this is a stub, used for reference
  super
end

.count(*vars) ⇒ Object

########## Elastics.count ##########

API Name: Search Shards API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-count.html


Elastics::Template::Api

count:

  • GET
  • "/<>/<>/_count"

Usage: Elastics.count :index => nil, :type => nil

Notice: You must pass the query to validate as the :data variable. You can pass the parameters as the :params variable.



335
336
337
338
# File 'lib/elastics/api_stubs.rb', line 335

def self.count(*vars)
  ## this is a stub, used for reference
  super
end

.delete(*vars) ⇒ Object

########## Elastics.delete ##########

API Name: Delete API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-delete.html


Elastics::Template::Api

delete:

  • DELETE
  • "/<>/<>/<>"

Usage: Elastics.delete :id => id, # required :type => nil, :index => nil

Notice: You must pass the :data variable.



128
129
130
131
# File 'lib/elastics/api_stubs.rb', line 128

def self.delete(*vars)
  ## this is a stub, used for reference
  super
end

.delete_index(*vars) ⇒ Object

########## Elastics.delete_index ##########

API Name: Delete Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-index.html


Elastics::Template::Api

delete_index:

  • DELETE
  • "/<>"

Usage: Elastics.delete_index :index => nil



620
621
622
623
# File 'lib/elastics/api_stubs.rb', line 620

def self.delete_index(*vars)
  ## this is a stub, used for reference
  super
end

.delete_index_alias(*vars) ⇒ Object

########## Elastics.delete_index_alias ##########

API Name: Index Aliases API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html


Elastics::Template::Api

delete_index_alias:

  • DELETE
  • "/<>/_alias/<>"

Usage: Elastics.delete_index_alias :alias => alias, # required :index => nil



901
902
903
904
# File 'lib/elastics/api_stubs.rb', line 901

def self.delete_index_alias(*vars)
  ## this is a stub, used for reference
  super
end

.delete_index_mapping(*vars) ⇒ Object

########## Elastics.delete_index_mapping ##########

API Name: Delete Mappings API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-mapping.html


Elastics::Template::Api

delete_index_mapping:

  • DELETE
  • "/<>/<>"

Usage: Elastics.delete_index_mapping :index => nil, :type => nil



831
832
833
834
# File 'lib/elastics/api_stubs.rb', line 831

def self.delete_index_mapping(*vars)
  ## this is a stub, used for reference
  super
end

.delete_index_template(*vars) ⇒ Object

########## Elastics.delete_index_template ##########

API Name: Index Templates API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html


Elastics::Template::Api

delete_index_template:

  • DELETE
  • "/_template/<