Module: Elastics::ApiStubs
- Included in:
- Elastics
- Defined in:
- lib/elastics/api_stubs.rb
Class Method Summary collapse
-
.analyze_index(*vars) ⇒ Object
########## Elastics.analyze_index ##########.
-
.cat(*vars) ⇒ Object
########## Elastics.cat ##########.
-
.close_index(*vars) ⇒ Object
########## Elastics.close_index ##########.
-
.cluster_health(*vars) ⇒ Object
########## Elastics.cluster_health ##########.
-
.cluster_nodes_hot_threads(*vars) ⇒ Object
########## Elastics.cluster_nodes_hot_threads ##########.
-
.cluster_nodes_info(*vars) ⇒ Object
########## Elastics.cluster_nodes_info ##########.
-
.cluster_nodes_stats(*vars) ⇒ Object
########## Elastics.cluster_nodes_stats ##########.
-
.cluster_pending_tasks(*vars) ⇒ Object
########## Elastics.cluster_pending_tasks ##########.
-
.cluster_reroute(*vars) ⇒ Object
########## Elastics.cluster_reroute ##########.
-
.cluster_state(*vars) ⇒ Object
########## Elastics.cluster_state ##########.
-
.cluster_stats(*vars) ⇒ Object
########## Elastics.cluster_stats ##########.
-
.count(*vars) ⇒ Object
########## Elastics.count ##########.
-
.delete(*vars) ⇒ Object
########## Elastics.delete ##########.
-
.delete_index(*vars) ⇒ Object
########## Elastics.delete_index ##########.
-
.delete_index_alias(*vars) ⇒ Object
########## Elastics.delete_index_alias ##########.
-
.delete_index_mapping(*vars) ⇒ Object
########## Elastics.delete_index_mapping ##########.
-
.delete_index_template(*vars) ⇒ Object
########## Elastics.delete_index_template ##########.
-
.delete_index_warmer(*vars) ⇒ Object
########## Elastics.delete_index_warmer ##########.
-
.delete_percolator(*vars) ⇒ Object
########## Elastics.delete_percolator ##########.
-
.explain(*vars) ⇒ Object
########## Elastics.explain ##########.
-
.flush_index(*vars) ⇒ Object
########## Elastics.flush_index ##########.
-
.get(*vars) ⇒ Object
########## Elastics.get ##########.
-
.get_cluster_settings(*vars) ⇒ Object
########## Elastics.get_cluster_settings ##########.
-
.get_field_mapping(*vars) ⇒ Object
########## Elastics.get_field_mapping ##########.
-
.get_index(*vars) ⇒ Object
########## Elastics.get_index ##########.
-
.get_index_alias(*vars) ⇒ Object
########## Elastics.get_index_alias ##########.
-
.get_index_aliases(*vars) ⇒ Object
########## Elastics.get_index_aliases ##########.
-
.get_index_mapping(*vars) ⇒ Object
########## Elastics.get_index_mapping ##########.
-
.get_index_settings(*vars) ⇒ Object
########## Elastics.get_index_settings ##########.
-
.get_index_template(*vars) ⇒ Object
########## Elastics.get_index_template ##########.
-
.get_index_warmer(*vars) ⇒ Object
########## Elastics.get_index_warmer ##########.
-
.get_source(*vars) ⇒ Object
########## Elastics.get_source ##########.
-
.index_clearcache(*vars) ⇒ Object
########## Elastics.index_clearcache ##########.
-
.index_recovery(*vars) ⇒ Object
########## Elastics.index_recovery ##########.
-
.index_segments(*vars) ⇒ Object
########## Elastics.index_segments ##########.
-
.index_stats(*vars) ⇒ Object
########## Elastics.index_stats ##########.
-
.index_status(*vars) ⇒ Object
########## Elastics.index_status ##########.
-
.index_template_exists(*vars) ⇒ Object
########## Elastics.index_template_exists ##########.
-
.indices_exists(*vars) ⇒ Object
########## Elastics.indices_exists ##########.
-
.match_all(*vars) ⇒ Object
########## Elastics.match_all ##########.
-
.more_like_this(*vars) ⇒ Object
########## Elastics.more_like_this ##########.
-
.multi_get_docs(*vars) ⇒ Object
########## Elastics.multi_get_docs ##########.
-
.multi_get_ids(*vars) ⇒ Object
########## Elastics.multi_get_ids ##########.
-
.multi_termvectors(*vars) ⇒ Object
########## Elastics.multi_termvectors ##########.
-
.open_index(*vars) ⇒ Object
########## Elastics.open_index ##########.
-
.optimize_index(*vars) ⇒ Object
########## Elastics.optimize_index ##########.
-
.percolate(*vars) ⇒ Object
########## Elastics.percolate ##########.
-
.percolate_count(*vars) ⇒ Object
########## Elastics.percolate_count ##########.
-
.post_bulk_string(*vars) ⇒ Object
########## Elastics.post_bulk_string ##########.
-
.post_index(*vars) ⇒ Object
########## Elastics.post_index ##########.
-
.post_index_aliases(*vars) ⇒ Object
########## Elastics.post_index_aliases ##########.
-
.post_store(*vars) ⇒ Object
########## Elastics.post_store ##########.
-
.put_cluster_settings(*vars) ⇒ Object
########## Elastics.put_cluster_settings ##########.
-
.put_index(*vars) ⇒ Object
########## Elastics.put_index ##########.
-
.put_index_alias(*vars) ⇒ Object
########## Elastics.put_index_alias ##########.
-
.put_index_mapping(*vars) ⇒ Object
########## Elastics.put_index_mapping ##########.
-
.put_index_template(*vars) ⇒ Object
########## Elastics.put_index_template ##########.
-
.put_index_warmer(*vars) ⇒ Object
########## Elastics.put_index_warmer ##########.
-
.put_percolator(*vars) ⇒ Object
########## Elastics.put_percolator ##########.
-
.refresh_index(*vars) ⇒ Object
########## Elastics.refresh_index ##########.
-
.search_by_id(*vars) ⇒ Object
########## Elastics.search_by_id ##########.
-
.search_exists(*vars) ⇒ Object
########## Elastics.search_exists ##########.
-
.search_shards(*vars) ⇒ Object
########## Elastics.search_shards ##########.
-
.store(*vars) ⇒ Object
########## Elastics.store ##########.
-
.synced_flush_index(*vars) ⇒ Object
########## Elastics.synced_flush_index ##########.
-
.termvectors(*vars) ⇒ Object
########## Elastics.termvectors ########## ------------------ Elastics::Template::API --- termvectors: - POST - "/<
>/< >/< >/_termvectors". -
.types_exists(*vars) ⇒ Object
########## Elastics.types_exists ##########.
-
.update(*vars) ⇒ Object
########## Elastics.update ##########.
-
.update_index_settings(*vars) ⇒ Object
########## Elastics.update_index_settings ##########.
-
.upgrade_index(*vars) ⇒ Object
########## Elastics.upgrade_index ##########.
-
.validate(*vars) ⇒ Object
########## Elastics.validate ##########.
Class Method Details
.analyze_index(*vars) ⇒ Object
########## Elastics.analyze_index ##########
API Name: Analyze API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-analyze.html
Elastics::Template::Api
analyze_index:
- GET
- "/<
>/_analyze"
Usage: Elastics.analyze_index :index => nil
Notice: You can pass the text to analyze as the :data variable (or the param :text). You can pass the parameters as the :params variable.
1021 1022 1023 1024 |
# File 'lib/elastics/api_stubs.rb', line 1021 def self.analyze_index(*vars) ## this is a stub, used for reference super end |
.cat(*vars) ⇒ Object
########## Elastics.cat ##########
API Name: Cat API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cat.html
Elastics::Template::Api
cat:
- GET
- "/"
Usage: Elastics.cat Notice: You must pass the :path variable or you can pass it as a simple string argument: Elastics.cat('/path')
1435 1436 1437 1438 |
# File 'lib/elastics/api_stubs.rb', line 1435 def self.cat(*vars) ## this is a stub, used for reference super end |
.close_index(*vars) ⇒ Object
########## Elastics.close_index ##########
API Name: Open/Close Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html
Elastics::Template::Api
close_index:
- POST
- "/<
>/_close"
Usage: Elastics.close_index :index => nil
688 689 690 691 |
# File 'lib/elastics/api_stubs.rb', line 688 def self.close_index(*vars) ## this is a stub, used for reference super end |
.cluster_health(*vars) ⇒ Object
########## Elastics.cluster_health ##########
API Name: Health API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-health.html
Elastics::Template::Api
cluster_health:
- GET
- "/_cluster/health/<
>"
Usage: Elastics.cluster_health :index => nil
Notice: You can pass the params as the :params variable.
1459 1460 1461 1462 |
# File 'lib/elastics/api_stubs.rb', line 1459 def self.cluster_health(*vars) ## this is a stub, used for reference super end |
.cluster_nodes_hot_threads(*vars) ⇒ Object
########## Elastics.cluster_nodes_hot_threads ##########
API Name: Nodes Hot Threads API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html
Elastics::Template::Api
cluster_nodes_hot_threads:
- GET
- "/_nodes/<<nodes= ~ >>/hot_threads"
Usage: Elastics.cluster_nodes_hot_threads :nodes => nil
1669 1670 1671 1672 |
# File 'lib/elastics/api_stubs.rb', line 1669 def self.cluster_nodes_hot_threads(*vars) ## this is a stub, used for reference super end |
.cluster_nodes_info(*vars) ⇒ Object
########## Elastics.cluster_nodes_info ##########
API Name: Nodes Info API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-info.html
Elastics::Template::Api
cluster_nodes_info:
- GET
- "/_nodes/<<nodes= ~ >>/<<info= ~ >>"
Usage: Elastics.cluster_nodes_info :nodes => nil, :info => nil
Notice: This template uses the _nodes shortcut.
1647 1648 1649 1650 |
# File 'lib/elastics/api_stubs.rb', line 1647 def self.cluster_nodes_info(*vars) ## this is a stub, used for reference super end |
.cluster_nodes_stats(*vars) ⇒ Object
########## Elastics.cluster_nodes_stats ##########
API Name: Nodes Stats API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-stats.html
Elastics::Template::Api
cluster_nodes_stats:
- GET
- "/_nodes/<<nodes= ~ >>/stats/<<stats= ~ >>"
Usage: Elastics.cluster_nodes_stats :nodes => nil, :stats => nil
Notice: You can pass the params as the :params variable. You must pass the data structure as the :data variable.
1622 1623 1624 1625 |
# File 'lib/elastics/api_stubs.rb', line 1622 def self.cluster_nodes_stats(*vars) ## this is a stub, used for reference super end |
.cluster_pending_tasks(*vars) ⇒ Object
########## Elastics.cluster_pending_tasks ##########
API Name: Pending Cluster Tasks API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-pending.html
Elastics::Template::Api
cluster_pending_tasks:
- GET
- "/_cluster/pending_tasks"
Usage: Elastics.cluster_pending_tasks Notice: You can pass the params as the :params variable.
1530 1531 1532 1533 |
# File 'lib/elastics/api_stubs.rb', line 1530 def self.cluster_pending_tasks(*vars) ## this is a stub, used for reference super end |
.cluster_reroute(*vars) ⇒ Object
########## Elastics.cluster_reroute ##########
API Name: Cluster Reroute API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-reroute.html
Elastics::Template::Api
cluster_reroute:
- POST
- "/_cluster/reroute"
Usage: Elastics.cluster_reroute Notice: You must pass the data structure as the :data variable.
1553 1554 1555 1556 |
# File 'lib/elastics/api_stubs.rb', line 1553 def self.cluster_reroute(*vars) ## this is a stub, used for reference super end |
.cluster_state(*vars) ⇒ Object
########## Elastics.cluster_state ##########
API Name: State API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-state.html
Elastics::Template::Api
cluster_state:
- GET
- "/_cluster/state/<<metrics= _all >>/<
>"
Usage: Elastics.cluster_state :metrics => "_all", :index => nil
Notice: You can pass the metrics as the :metrics variable.
1484 1485 1486 1487 |
# File 'lib/elastics/api_stubs.rb', line 1484 def self.cluster_state(*vars) ## this is a stub, used for reference super end |
.cluster_stats(*vars) ⇒ Object
########## Elastics.cluster_stats ##########
API Name: Stats API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-stats.html
Elastics::Template::Api
cluster_stats:
- GET
- "/_cluster/stats"
Usage: Elastics.cluster_stats Notice: You can pass the params as the :params variable.
1507 1508 1509 1510 |
# File 'lib/elastics/api_stubs.rb', line 1507 def self.cluster_stats(*vars) ## this is a stub, used for reference super end |
.count(*vars) ⇒ Object
########## Elastics.count ##########
API Name: Search Shards API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-count.html
Elastics::Template::Api
count:
- GET
- "/<
>/< >/_count"
Usage: Elastics.count :index => nil, :type => nil
Notice: You must pass the query to validate as the :data variable. You can pass the parameters as the :params variable.
335 336 337 338 |
# File 'lib/elastics/api_stubs.rb', line 335 def self.count(*vars) ## this is a stub, used for reference super end |
.delete(*vars) ⇒ Object
########## Elastics.delete ##########
API Name: Delete API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-delete.html
Elastics::Template::Api
delete:
- DELETE
- "/<
>/< >/< >"
Usage: Elastics.delete :id => id, # required :type => nil, :index => nil
Notice: You must pass the :data variable.
128 129 130 131 |
# File 'lib/elastics/api_stubs.rb', line 128 def self.delete(*vars) ## this is a stub, used for reference super end |
.delete_index(*vars) ⇒ Object
########## Elastics.delete_index ##########
API Name: Delete Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-index.html
Elastics::Template::Api
delete_index:
- DELETE
- "/<
>"
Usage: Elastics.delete_index :index => nil
620 621 622 623 |
# File 'lib/elastics/api_stubs.rb', line 620 def self.delete_index(*vars) ## this is a stub, used for reference super end |
.delete_index_alias(*vars) ⇒ Object
########## Elastics.delete_index_alias ##########
API Name: Index Aliases API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html
Elastics::Template::Api
delete_index_alias:
- DELETE
- "/<
>/_alias/< >"
Usage: Elastics.delete_index_alias :alias => alias, # required :index => nil
901 902 903 904 |
# File 'lib/elastics/api_stubs.rb', line 901 def self.delete_index_alias(*vars) ## this is a stub, used for reference super end |
.delete_index_mapping(*vars) ⇒ Object
########## Elastics.delete_index_mapping ##########
API Name: Delete Mappings API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-mapping.html
Elastics::Template::Api
delete_index_mapping:
- DELETE
- "/<
>/< >"
Usage: Elastics.delete_index_mapping :index => nil, :type => nil
831 832 833 834 |
# File 'lib/elastics/api_stubs.rb', line 831 def self.delete_index_mapping(*vars) ## this is a stub, used for reference super end |
.delete_index_template(*vars) ⇒ Object
########## Elastics.delete_index_template ##########
API Name: Index Templates API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html
Elastics::Template::Api
delete_index_template:
- DELETE
- "/_template/<>"
Usage: Elastics.delete_index_template :template => template # required
1043 1044 1045 1046 |
# File 'lib/elastics/api_stubs.rb', line 1043 def self.delete_index_template(*vars) ## this is a stub, used for reference super end |
.delete_index_warmer(*vars) ⇒ Object
########## Elastics.delete_index_warmer ##########
API Name: Warmers API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html
Elastics::Template::Api
delete_index_warmer:
- DELETE
- "/<
>/_warmer/< >"
Usage: Elastics.delete_index_warmer :warmer => warmer, # required :index => nil
1134 1135 1136 1137 |
# File 'lib/elastics/api_stubs.rb', line 1134 def self.delete_index_warmer(*vars) ## this is a stub, used for reference super end |
.delete_percolator(*vars) ⇒ Object
########## Elastics.delete_percolator ##########
API Name: Percolator API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html
Elastics::Template::Api
delete_percolator:
- DELETE
- "/<
>/.percolator/< >"
Usage: Elastics.delete_percolator :id => id, # required :index => nil
436 437 438 439 |
# File 'lib/elastics/api_stubs.rb', line 436 def self.delete_percolator(*vars) ## this is a stub, used for reference super end |
.explain(*vars) ⇒ Object
########## Elastics.explain ##########
API Name: Validate API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-explain.html
Elastics::Template::Api
explain:
- GET
- "/<
>/< >/<<id= ~ >>/_explain"
Usage: Elastics.explain :index => nil, :type => nil, :id => nil
Notice: You must pass the query to explain as the :data variable. You can pass the parameters as the :params variable.
413 414 415 416 |
# File 'lib/elastics/api_stubs.rb', line 413 def self.explain(*vars) ## this is a stub, used for reference super end |
.flush_index(*vars) ⇒ Object
########## Elastics.flush_index ##########
API Name: Flush API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-flush.html
Elastics::Template::Api
flush_index:
- POST
- "/<
>/_flush"
Usage: Elastics.flush_index :index => nil
Notice: You can pass the parameters as the :params variable.
1318 1319 1320 1321 |
# File 'lib/elastics/api_stubs.rb', line 1318 def self.flush_index(*vars) ## this is a stub, used for reference super end |
.get(*vars) ⇒ Object
########## Elastics.get ##########
API Name: Get API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-get.html
Elastics::Template::Api
get:
- GET
- "/<
>/< >/< >"
Usage: Elastics.get :id => id, # required :type => nil, :index => nil
78 79 80 81 |
# File 'lib/elastics/api_stubs.rb', line 78 def self.get(*vars) ## this is a stub, used for reference super end |
.get_cluster_settings(*vars) ⇒ Object
########## Elastics.get_cluster_settings ##########
API Name: Cluster Update Settings API URL: http://www.elasticsearch.org/guide/reference/api/admin-cluster-update-settings
Elastics::Template::Api
get_cluster_settings:
- GET
- "/_cluster/settings"
Usage: Elastics.get_cluster_settings
1574 1575 1576 1577 |
# File 'lib/elastics/api_stubs.rb', line 1574 def self.get_cluster_settings(*vars) ## this is a stub, used for reference super end |
.get_field_mapping(*vars) ⇒ Object
########## Elastics.get_field_mapping ##########
API Name: Get Field Mappings API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-field-mapping.html
Elastics::Template::Api
get_field_mapping:
- GET
- "/<
>/_mapping/< >/field/< >"
Usage: Elastics.get_field_mapping :field => field, # required :type => nil, :index => nil
784 785 786 787 |
# File 'lib/elastics/api_stubs.rb', line 784 def self.get_field_mapping(*vars) ## this is a stub, used for reference super end |
.get_index(*vars) ⇒ Object
########## Elastics.get_index ##########
API Name: Get Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-index.html
Elastics::Template::Api
get_index:
- GET
- "/<
>/<<features= ~ >>"
Usage: Elastics.get_index :index => nil, :features => nil
643 644 645 646 |
# File 'lib/elastics/api_stubs.rb', line 643 def self.get_index(*vars) ## this is a stub, used for reference super end |
.get_index_alias(*vars) ⇒ Object
########## Elastics.get_index_alias ##########
API Name: Index Aliases API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html
Elastics::Template::Api
get_index_alias:
- GET
- "/<
>/_alias/<<alias= '*' >>"
Usage: Elastics.get_index_alias :index => nil, :alias => "*"
924 925 926 927 |
# File 'lib/elastics/api_stubs.rb', line 924 def self.get_index_alias(*vars) ## this is a stub, used for reference super end |
.get_index_aliases(*vars) ⇒ Object
########## Elastics.get_index_aliases ##########
API Name: Index Aliases API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html
Elastics::Template::Api
get_index_aliases:
- GET
- "/<
>/_aliases"
Usage: Elastics.get_index_aliases :index => nil
853 854 855 856 |
# File 'lib/elastics/api_stubs.rb', line 853 def self.get_index_aliases(*vars) ## this is a stub, used for reference super end |
.get_index_mapping(*vars) ⇒ Object
########## Elastics.get_index_mapping ##########
API Name: Get Mappings API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-mapping.html
Elastics::Template::Api
get_index_mapping:
- GET
- "/<
>/_mapping/< >"
Usage: Elastics.get_index_mapping :index => nil, :type => nil
760 761 762 763 |
# File 'lib/elastics/api_stubs.rb', line 760 def self.get_index_mapping(*vars) ## this is a stub, used for reference super end |
.get_index_settings(*vars) ⇒ Object
########## Elastics.get_index_settings ##########
API Name: Get Indices Settings API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-settings.html
Elastics::Template::Api
get_index_settings:
- GET
- "/<
>/_settings"
Usage: Elastics.get_index_settings :index => nil
996 997 998 999 |
# File 'lib/elastics/api_stubs.rb', line 996 def self.get_index_settings(*vars) ## this is a stub, used for reference super end |
.get_index_template(*vars) ⇒ Object
########## Elastics.get_index_template ##########
API Name: Index Templates API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html
Elastics::Template::Api
get_index_template:
- GET
- "/_template/<<template= ~ >>"
Usage: Elastics.get_index_template :template => nil
1065 1066 1067 1068 |
# File 'lib/elastics/api_stubs.rb', line 1065 def self.get_index_template(*vars) ## this is a stub, used for reference super end |
.get_index_warmer(*vars) ⇒ Object
########## Elastics.get_index_warmer ##########
API Name: Warmers API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html
Elastics::Template::Api
get_index_warmer:
- GET
- "/<
>/_warmer/<<warmer= ~ >>"
Usage: Elastics.get_index_warmer :index => nil, :warmer => nil
1183 1184 1185 1186 |
# File 'lib/elastics/api_stubs.rb', line 1183 def self.get_index_warmer(*vars) ## this is a stub, used for reference super end |
.get_source(*vars) ⇒ Object
########## Elastics.get_source ##########
API Name: Get API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-get.html
Elastics::Template::Api
get_source:
- GET
- "/<
>/< >/< >/_source"
Usage: Elastics.get_source :id => id, # required :type => nil, :index => nil
102 103 104 105 |
# File 'lib/elastics/api_stubs.rb', line 102 def self.get_source(*vars) ## this is a stub, used for reference super end |
.index_clearcache(*vars) ⇒ Object
########## Elastics.index_clearcache ##########
API Name: Recovery API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-clearcache.html
Elastics::Template::Api
index_clearcache:
- POST
- "/<
>/_cache/clear"
Usage: Elastics.index_clearcache :index => nil
1294 1295 1296 1297 |
# File 'lib/elastics/api_stubs.rb', line 1294 def self.index_clearcache(*vars) ## this is a stub, used for reference super end |
.index_recovery(*vars) ⇒ Object
########## Elastics.index_recovery ##########
API Name: Recovery API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-recovery.html
Elastics::Template::Api
index_recovery:
- GET
- "/<
>/_recovery"
Usage: Elastics.index_recovery :index => nil
1272 1273 1274 1275 |
# File 'lib/elastics/api_stubs.rb', line 1272 def self.index_recovery(*vars) ## this is a stub, used for reference super end |
.index_segments(*vars) ⇒ Object
########## Elastics.index_segments ##########
API Name: Segments API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-segments.html
Elastics::Template::Api
index_segments:
- GET
- "/<
>/_segments"
Usage: Elastics.index_segments :index => nil
1250 1251 1252 1253 |
# File 'lib/elastics/api_stubs.rb', line 1250 def self.index_segments(*vars) ## this is a stub, used for reference super end |
.index_stats(*vars) ⇒ Object
########## Elastics.index_stats ##########
API Name: Stats API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-stats.html
Elastics::Template::Api
index_stats:
- GET
- "/<
>/_stats/<<stats= ~ >>"
Usage: Elastics.index_stats :index => nil, :stats => nil
1228 1229 1230 1231 |
# File 'lib/elastics/api_stubs.rb', line 1228 def self.index_stats(*vars) ## this is a stub, used for reference super end |
.index_status(*vars) ⇒ Object
########## Elastics.index_status ##########
API Name: Status API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-status.html
Elastics::Template::Api
index_status:
- GET
- "/<
>/_status"
Usage: Elastics.index_status :index => nil
1205 1206 1207 1208 |
# File 'lib/elastics/api_stubs.rb', line 1205 def self.index_status(*vars) ## this is a stub, used for reference super end |
.index_template_exists(*vars) ⇒ Object
########## Elastics.index_template_exists ##########
API Name: Index Templates API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html
Elastics::Template::Api
index_template_exists:
- HEAD
- "/_template/<>"
Usage: Elastics.index_template_exists :template => template # required
1087 1088 1089 1090 |
# File 'lib/elastics/api_stubs.rb', line 1087 def self.index_template_exists(*vars) ## this is a stub, used for reference super end |
.indices_exists(*vars) ⇒ Object
########## Elastics.indices_exists ##########
API Name: Indices Exists API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-exists.html
Elastics::Template::Api
indices_exists:
- HEAD
- "/<
>"
Usage: Elastics.indices_exists :index => nil
665 666 667 668 |
# File 'lib/elastics/api_stubs.rb', line 665 def self.indices_exists(*vars) ## this is a stub, used for reference super end |
.match_all(*vars) ⇒ Object
########## Elastics.match_all ##########
API Name: API URL:
Elastics::Template::Api
match_all:
- GET
- "/<
>/< >/_search" - query:
match_all: {}
Usage: Elastics.match_all :index => nil, :type => nil
Notice: Not a real API method, but handy.
1696 1697 1698 1699 |
# File 'lib/elastics/api_stubs.rb', line 1696 def self.match_all(*vars) ## this is a stub, used for reference super end |
.more_like_this(*vars) ⇒ Object
########## Elastics.more_like_this ##########
API Name: More Like This API URL: http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/search-more-like-this.html
Elastics::Template::Api
more_like_this:
- GET
- "/<
>/< >/< >/_mlt"
Usage: Elastics.more_like_this :id => id, # required :type => nil, :index => nil
Notice: You can pass the search API as :data variable.
537 538 539 540 |
# File 'lib/elastics/api_stubs.rb', line 537 def self.more_like_this(*vars) ## this is a stub, used for reference super end |
.multi_get_docs(*vars) ⇒ Object
########## Elastics.multi_get_docs ##########
API Name: Multi Get API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-multi-get.html
Elastics::Template::Api
multi_get_docs:
- GET
- "/<
>/< >/_mget" - docs: "<< docs >>"
Usage: Elastics.multi_get_docs :docs => docs, # required :type => nil, :index => nil
Notice: You must pass the :docs array.
210 211 212 213 |
# File 'lib/elastics/api_stubs.rb', line 210 def self.multi_get_docs(*vars) ## this is a stub, used for reference super end |
.multi_get_ids(*vars) ⇒ Object
########## Elastics.multi_get_ids ##########
API Name: Multi Get API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-multi-get.html
Elastics::Template::Api
multi_get_ids:
- GET
- "/<
>/< >/_mget" - ids: "<< ids >>"
Usage: Elastics.multi_get_ids :ids => ids, # required :type => nil, :index => nil
Notice: You must pass the :ids array.
182 183 184 185 |
# File 'lib/elastics/api_stubs.rb', line 182 def self.multi_get_ids(*vars) ## this is a stub, used for reference super end |
.multi_termvectors(*vars) ⇒ Object
########## Elastics.multi_termvectors ##########
API Name: Multi Termvectors API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-multi-termvectors.html
Elastics::Template::Api
multi_termvectors:
- POST
- "/<
>/< >/_mtermvectors" - docs: "<<docs= ~ >>"
Usage: Elastics.multi_termvectors :index => nil, :type => nil, :docs => nil
Notice: You must pass the docs array as the :docs variable or use the :data variable for the simplified request.
285 286 287 288 |
# File 'lib/elastics/api_stubs.rb', line 285 def self.multi_termvectors(*vars) ## this is a stub, used for reference super end |
.open_index(*vars) ⇒ Object
########## Elastics.open_index ##########
API Name: Open/Close Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html
Elastics::Template::Api
open_index:
- POST
- "/<
>/_open"
Usage: Elastics.open_index :index => nil
710 711 712 713 |
# File 'lib/elastics/api_stubs.rb', line 710 def self.open_index(*vars) ## this is a stub, used for reference super end |
.optimize_index(*vars) ⇒ Object
########## Elastics.optimize_index ##########
API Name: Optimize API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-optimize.html
Elastics::Template::Api
optimize_index:
- POST
- "/<
>/_optimize"
Usage: Elastics.optimize_index :index => nil
Notice: You can pass the parameters as the :params variable.
1388 1389 1390 1391 |
# File 'lib/elastics/api_stubs.rb', line 1388 def self.optimize_index(*vars) ## this is a stub, used for reference super end |
.percolate(*vars) ⇒ Object
########## Elastics.percolate ##########
API Name: Percolator API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html
Elastics::Template::Api
percolate:
- GET
- "/<
>/< >/_percolate"
Usage: Elastics.percolate :index => nil, :type => nil
Notice: You must pass the the document (and additional queries) as :data variable.
461 462 463 464 |
# File 'lib/elastics/api_stubs.rb', line 461 def self.percolate(*vars) ## this is a stub, used for reference super end |
.percolate_count(*vars) ⇒ Object
########## Elastics.percolate_count ##########
API Name: Percolator API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html
Elastics::Template::Api
percolate_count:
- GET
- "/<
>/< >/_percolate/count"
Usage: Elastics.percolate_count :index => nil, :type => nil
Notice: You must pass the the document (and additional queries) as :data variable.
486 487 488 489 |
# File 'lib/elastics/api_stubs.rb', line 486 def self.percolate_count(*vars) ## this is a stub, used for reference super end |
.post_bulk_string(*vars) ⇒ Object
########## Elastics.post_bulk_string ##########
API Name: Bulk API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-bulk.html
Elastics::Template::Api
post_bulk_string:
- POST
- "/_bulk"
- "<< bulk_string >>"
Usage: Elastics.post_bulk_string :bulk_string => bulk_string # required
Notice: You must pass the :docs array.
236 237 238 239 |
# File 'lib/elastics/api_stubs.rb', line 236 def self.post_bulk_string(*vars) ## this is a stub, used for reference super end |
.post_index(*vars) ⇒ Object
########## Elastics.post_index ##########
API Name: Create Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-create-index.html
Elastics::Template::Api
post_index:
- POST
- "/<
>" - settings:
number_of_shards: "<<number_of_shards= 5 >>" number_of_replicas: "<<number_of_replicas= 1 >>"
Usage: Elastics.post_index :index => nil, :number_of_shards => 5, :number_of_replicas => 1
Notice: You can also pass the complete data structure as :data variable, so passing settings, mappings, warmers, aliases, ...
597 598 599 600 |
# File 'lib/elastics/api_stubs.rb', line 597 def self.post_index(*vars) ## this is a stub, used for reference super end |
.post_index_aliases(*vars) ⇒ Object
########## Elastics.post_index_aliases ##########
API Name: Index Aliases API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html
Elastics::Template::Api
post_index_aliases:
- POST
- "/_aliases"
- actions: "<
>"
Usage: Elastics.post_index_aliases :actions => actions # required
Notice: This is the generic interface allowing all the options. You can pass the :actions array or the aliases API structure as the :data variable.
878 879 880 881 |
# File 'lib/elastics/api_stubs.rb', line 878 def self.post_index_aliases(*vars) ## this is a stub, used for reference super end |
.post_store(*vars) ⇒ Object
########## Elastics.post_store ##########
API Name: Index API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-index_.html
Elastics::Template::Api
post_store:
- POST
- "/<
>/< >"
Usage: Elastics.post_store :index => nil, :type => nil
Notice: The id is assigned by elasticsearch; you must pass the :data variable.
53 54 55 56 |
# File 'lib/elastics/api_stubs.rb', line 53 def self.post_store(*vars) ## this is a stub, used for reference super end |
.put_cluster_settings(*vars) ⇒ Object
########## Elastics.put_cluster_settings ##########
API Name: Cluster Update Settings API URL: http://www.elasticsearch.org/guide/reference/api/admin-cluster-update-settings
Elastics::Template::Api
put_cluster_settings:
- PUT
- "/_cluster/settings"
Usage: Elastics.put_cluster_settings Notice: You must pass the data structure as the :data variable.
1597 1598 1599 1600 |
# File 'lib/elastics/api_stubs.rb', line 1597 def self.put_cluster_settings(*vars) ## this is a stub, used for reference super end |
.put_index(*vars) ⇒ Object
########## Elastics.put_index ##########
API Name: Create Index API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-create-index.html
Elastics::Template::Api
put_index:
- PUT
- "/<
>" - settings:
number_of_shards: "<<number_of_shards= 5 >>" number_of_replicas: "<<number_of_replicas= 1 >>"
Usage: Elastics.put_index :index => nil, :number_of_shards => 5, :number_of_replicas => 1
Notice: You can also pass the complete data structure as :data variable, so passing settings, mappings, warmers, aliases, ...
567 568 569 570 |
# File 'lib/elastics/api_stubs.rb', line 567 def self.put_index(*vars) ## this is a stub, used for reference super end |
.put_index_alias(*vars) ⇒ Object
########## Elastics.put_index_alias ##########
API Name: Index Aliases API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html
Elastics::Template::Api
put_index_alias:
- PUT
- "/<
>/_alias/< >"
Usage: Elastics.put_index_alias :alias => alias, # required :index => nil
Notice: This is the single index alias. You can pass other options as the :data variable.
949 950 951 952 |
# File 'lib/elastics/api_stubs.rb', line 949 def self.put_index_alias(*vars) ## this is a stub, used for reference super end |
.put_index_mapping(*vars) ⇒ Object
########## Elastics.put_index_mapping ##########
API Name: Put Mappings API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-put-mapping.html
Elastics::Template::Api
put_index_mapping:
- PUT
- "/<
>/_mapping/< >" - "<
>": properties: "<<properties>>"
Usage: Elastics.put_index_mapping :properties => properties, # required :type => nil, :index => nil
736 737 738 739 |
# File 'lib/elastics/api_stubs.rb', line 736 def self.put_index_mapping(*vars) ## this is a stub, used for reference super end |
.put_index_template(*vars) ⇒ Object
########## Elastics.put_index_template ##########
API Name: Index Templates API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html
Elastics::Template::Api
put_index_template:
- PUT
- "/_template/<>"
Usage: Elastics.put_index_template :template => template # required
Notice: You must pass the template structure as the :data variable.
1111 1112 1113 1114 |
# File 'lib/elastics/api_stubs.rb', line 1111 def self.put_index_template(*vars) ## this is a stub, used for reference super end |
.put_index_warmer(*vars) ⇒ Object
########## Elastics.put_index_warmer ##########
API Name: Warmers API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html
Elastics::Template::Api
put_index_warmer:
- PUT
- "/<
>/< >/_warmer/< >"
Usage: Elastics.put_index_warmer :warmer => warmer, # required :type => nil, :index => nil
Notice: You must pass the warmer structure as the :data variable.
1160 1161 1162 1163 |
# File 'lib/elastics/api_stubs.rb', line 1160 def self.put_index_warmer(*vars) ## this is a stub, used for reference super end |
.put_percolator(*vars) ⇒ Object
########## Elastics.put_percolator ##########
API Name: Percolator API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html
Elastics::Template::Api
put_percolator:
- PUT
- "/<
>/.percolator/< >"
Usage: Elastics.put_percolator :id => id, # required :index => nil
Notice: You must pass the the document (and additional queries) as :data variable.
511 512 513 514 |
# File 'lib/elastics/api_stubs.rb', line 511 def self.put_percolator(*vars) ## this is a stub, used for reference super end |
.refresh_index(*vars) ⇒ Object
########## Elastics.refresh_index ##########
API Name: Refresh API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-refresh.html
Elastics::Template::Api
refresh_index:
- POST
- "/<
>/_refresh"
Usage: Elastics.refresh_index :index => nil
1364 1365 1366 1367 |
# File 'lib/elastics/api_stubs.rb', line 1364 def self.refresh_index(*vars) ## this is a stub, used for reference super end |
.search_by_id(*vars) ⇒ Object
########## Elastics.search_by_id ##########
API Name: API URL:
Elastics::Template::Api
search_by_id:
- GET
- "/<
>/< >/_search" - query:
term: _id: "<<id>>"
Usage: Elastics.search_by_id :id => id, # required :type => nil, :index => nil
Notice: Get a document without using the get API and without raising any error if it is missing.
1725 1726 1727 1728 |
# File 'lib/elastics/api_stubs.rb', line 1725 def self.search_by_id(*vars) ## this is a stub, used for reference super end |
.search_exists(*vars) ⇒ Object
########## Elastics.search_exists ##########
API Name: Search Exists API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-exists.html
Elastics::Template::Api
search_exists:
- GET
- "/<
>/< >/<<id= ~ >>/_search/exists"
Usage: Elastics.search_exists :index => nil, :type => nil, :id => nil
Notice: You must pass the query to validate as the :data variable. You can pass the parameters as the :params variable.
361 362 363 364 |
# File 'lib/elastics/api_stubs.rb', line 361 def self.search_exists(*vars) ## this is a stub, used for reference super end |
.search_shards(*vars) ⇒ Object
########## Elastics.search_shards ##########
API Name: Search Shards API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-shards.html
Elastics::Template::Api
search_shards:
- GET
- "/<
>/< >/_search_shards"
Usage: Elastics.search_shards :index => nil, :type => nil
Notice: You can pass the parameters as the :params variable.
310 311 312 313 |
# File 'lib/elastics/api_stubs.rb', line 310 def self.search_shards(*vars) ## this is a stub, used for reference super end |
.store(*vars) ⇒ Object
########## Elastics.store ##########
API Name: Index API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-index_.html
Elastics::Template::Api
store:
- PUT
- "/<
>/< >/< >"
Usage: Elastics.store :id => id, # required :type => nil, :index => nil
Notice: You must pass the :data variable.
27 28 29 30 |
# File 'lib/elastics/api_stubs.rb', line 27 def self.store(*vars) ## this is a stub, used for reference super end |
.synced_flush_index(*vars) ⇒ Object
########## Elastics.synced_flush_index ##########
API Name: Synced Flush API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-synced-flush.html
Elastics::Template::Api
synced_flush_index:
- POST
- "/<
>/_flush/synced"
Usage: Elastics.synced_flush_index :index => nil
Notice: You can pass the parameters as the :params variable.
1342 1343 1344 1345 |
# File 'lib/elastics/api_stubs.rb', line 1342 def self.synced_flush_index(*vars) ## this is a stub, used for reference super end |
.termvectors(*vars) ⇒ Object
########## Elastics.termvectors ##########
Elastics::Template::API
termvectors:
- POST
- "/<
>/< >/< >/_termvectors"
Usage: Elastics.termvectors :id => id, # required :type => nil, :index => nil
257 258 259 260 |
# File 'lib/elastics/api_stubs.rb', line 257 def self.termvectors(*vars) ## this is a stub, used for reference super end |
.types_exists(*vars) ⇒ Object
########## Elastics.types_exists ##########
API Name: Types Exists API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-types-exists.html
Elastics::Template::Api
types_exists:
- HEAD
- "/<
>/< >"
Usage: Elastics.types_exists :index => nil, :type => nil
807 808 809 810 |
# File 'lib/elastics/api_stubs.rb', line 807 def self.types_exists(*vars) ## this is a stub, used for reference super end |
.update(*vars) ⇒ Object
########## Elastics.update ##########
API Name: Update API API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-update.html
Elastics::Template::Api
update:
- POST
- "/<
>/< >/< >/_update"
Usage: Elastics.update :id => id, # required :type => nil, :index => nil
Notice: You must pass script or doc and the other options as the :data variable.
155 156 157 158 |
# File 'lib/elastics/api_stubs.rb', line 155 def self.update(*vars) ## this is a stub, used for reference super end |
.update_index_settings(*vars) ⇒ Object
########## Elastics.update_index_settings ##########
API Name: Update Indices Settings API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-update-settings.html
Elastics::Template::Api
update_index_settings:
- PUT
- "/<
>/_settings"
Usage: Elastics.update_index_settings :index => nil
Notice: You can pass the settings structure as the :data variable.
973 974 975 976 |
# File 'lib/elastics/api_stubs.rb', line 973 def self.update_index_settings(*vars) ## this is a stub, used for reference super end |
.upgrade_index(*vars) ⇒ Object
########## Elastics.upgrade_index ##########
API Name: Upgrade API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-upgrade.html
Elastics::Template::Api
upgrade_index:
- POST
- "/<
>/_upgrade"
Usage: Elastics.upgrade_index :index => nil
Notice: You can pass the parameters as the :params variable.
1412 1413 1414 1415 |
# File 'lib/elastics/api_stubs.rb', line 1412 def self.upgrade_index(*vars) ## this is a stub, used for reference super end |
.validate(*vars) ⇒ Object
########## Elastics.validate ##########
API Name: Validate API URL: https://www.elastic.co/guide/en/elasticsearch/reference/current/search-validate.html
Elastics::Template::Api
validate:
- GET
- "/<
>/< >/<<id= ~ >>/_validate/query"
Usage: Elastics.validate :index => nil, :type => nil, :id => nil
Notice: You must pass the query to validate as the :data variable. You can pass the parameters as the :params variable.
387 388 389 390 |
# File 'lib/elastics/api_stubs.rb', line 387 def self.validate(*vars) ## this is a stub, used for reference super end |